#ifndef NT2_INCLUDE_FUNCTIONS_LOG2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOG2_HPP_INCLUDED

#include <nt2/exponential/include/functions/log2.hpp>

#endif
